IndoorDirectionsIcons class
Icons to indicate origin and destination on route. Please refer this link for more details.
Constructors
- IndoorDirectionsIcons({WoosIcon? destinationIcon, WoosIcon? originIcon})
- Default constructor. Creates IndoorDirectionsIcons object.
-
IndoorDirectionsIcons.fromJson(Map<
String, dynamic> json) - Creates IndoorDirectionsIcons object from the given JSON object
Properties
- destinationIcon ↔ WoosIcon?
-
Represents destination icon of the path.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- originIcon ↔ WoosIcon?
-
Represents origin icon of the path.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Returns JSON representation of the object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited